@@ -249,6 +249,8 @@ class Face():
                             465
                             ]
 
+    forehead_center_index = [151]
+    
     forehead_indices = [
         301,
         298,
@@ -350,7 +352,24 @@ class Face():
         338
     ]
 
-
+    face_forhead_indices = [
+        10,
+        109,
+        67,
+        103,
+        104,
+        105,
+        66,
+        107,
+        9,
+        336,
+        296,
+        334,
+        333,
+        332,
+        297,
+        338
+    ]
     all_face_features = list(range(468))
     def __init__(self, landmarks:NamedTuple = None, image_shape: tuple = (640, 480)):
         """Creates an instance of Face
@@ -771,8 +790,8 @@ class Face():
 
         face_2d_positions = self.npLandmarks[self.face_reference_landmark_ids,:2]
         (success, face_ori, face_pos, _) = cv2.solvePnPRansac(
-                                                    self.face_3d_reference_positions.astype(np.float),
-                                                    face_2d_positions.astype(np.float), 
+                                                    self.face_3d_reference_positions.astype(np.float32),
+                                                    face_2d_positions.astype(np.float32), 
                                                     camera_matrix, 
                                                     dist_coeffs,
                                                     flags=cv2.SOLVEPNP_ITERATIVE)
@@ -781,6 +800,8 @@ class Face():
             return None, None
 
         # save posture
+        face_pos[0]*=-1
+        face_pos[1]*=-1
         self.pos = face_pos
         self.ori = face_ori
 
@@ -1208,6 +1229,7 @@ class Face():
             image (np.ndarray): Image to extract the face from
             src_triangles (list): The delaulay triangles indices (look at triangulate)
             landmark_indices (list, optional): The list of landmarks to be used (the same list used for the triangulate method that allowed the extraction of the triangles). Defaults to None.
+            margins (tuple, optional): Margin around the face (left, top, right, bottom). Defaults to (0,0,0,0).
 
         Returns:
             np.ndarray: Face drawn on a black background (the size of the image is equal of that of the face in the original image)
@@ -1220,9 +1242,29 @@ class Face():
             landmarks = self.npLandmarks[:, :2]
         else:
             landmarks = self.npLandmarks[landmark_indices, :2]
-        p1 = landmarks.min(axis=0)-np.array(margins[0:2])
-        p2 = landmarks.max(axis=0)+np.array(margins[2:4])
-        return image[int(p1[1]):int(p2[1]),int(p1[0]):int(p2[0])]
+
+        # Calculate original dimensions of image
+        height, width = image.shape[:2]
+
+        # Calculate new dimensions of cropped image
+        x1, y1 = landmarks.min(axis=0) - np.array(margins[0:2])
+        x2, y2 = landmarks.max(axis=0) + np.array(margins[2:4])
+        new_width = int(x2 - x1)
+        new_height = int(y2 - y1)
+
+        # Check if new dimensions are within original image frame
+        if x1 < 0:
+            x1 = 0
+        if y1 < 0:
+            y1 = 0
+        if x2 > width:
+            x2 = width
+        if y2 > height:
+            y2 = height
+
+        # Crop the image using adjusted dimensions
+        return image[int(y1):int(y2), int(x1):int(x2),...]
+
 
     def getFace(self, image:np.ndarray, src_triangles:list(), landmark_indices:list=None)->np.ndarray:
         """Gets an image of the face extracted from the original image (only the face with no background)
@@ -1676,4 +1718,4 @@ class Face():
         
         return in_range
 
-        
\ No newline at end of file
+        
